#
# spec file for package catfish
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define series 1.4
Name:           catfish
Version:        1.4.7
Release:        1.1
Summary:        Versatile File Searching Tool
License:        GPL-2.0-or-later
Group:          Productivity/File utilities
Url:            https://docs.xfce.org/apps/catfish/start
Source:         http://archive.xfce.org/src/apps/catfish/1.4/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  python3-distutils-extra
BuildRequires:  rsvg-view
BuildRequires:  update-desktop-files
# Needed for typelib() - Requires.
BuildRequires:  gobject-introspection
# Checking module dependencies...
BuildRequires:  gtk3-devel >= 3.16
BuildRequires:  python3-gobject
BuildRequires:  python3-gobject-Gdk
BuildRequires:  python3-pexpect
BuildRequires:  python3-xml
#uildRequires:  zeitgeist
# ...OK
Requires:       findutils-locate
Requires:       gdk-pixbuf-loader-rsvg
Requires:       gsettings-backend-dconf
Requires:       python3-cairo
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-gobject-cairo
Requires:       python3-pexpect
Requires:       python3-xml
Requires:       sudo
Suggests:       zeitgeist
Recommends:     %{name}-lang
BuildArch:      noarch

%description
Catfish is a GTK+ search utility written in python. Its search is powered by
/usr/bin/find and /usr/bin/locate, with search suggestions provided by
zeitgeist.

%lang_package

%prep
%setup -q

%build
python3 ./setup.py build -g

%install
python3 ./setup.py install -O1 \
    --prefix="%{_prefix}" \
    --root="%{buildroot}"
rm -rf %{buildroot}%{_datadir}/doc/%{name}
# Fix: non-executable-script
pushd %{buildroot}
for _file in $(grep -rl '^\#\!\/'); do
  find -name ${_file##*/} -type f -not -perm /111 -exec sed '/^\#\!\//d' -i {} \+
  find -name ${_file##*/} -type f -perm /111 -exec sed '/^\#\!\/.\+py/s/env\ \+//' -i {} \+
done
%py3_compile -O .%{python3_sitelib}
popd
sed -i "s/\(Exec=\).*/\1%{name}/" %{buildroot}%{_datadir}/applications/org.xfce.Catfish.desktop
for i in 16 24 32 48; do
    install -dm 0755 %{buildroot}%{_datadir}/icons/hicolor/$i\x$i/apps
    rsvg-convert -h $i -w $i data/media/catfish.svg -o %{buildroot}%{_datadir}/icons/hicolor/$i\x$i/apps/%{name}.png
done
mkdir -p %{buildroot}%{_datadir}/appdata
mv %{buildroot}%{_datadir}/{metainfo,appdata}/%{name}.appdata.xml

%suse_update_desktop_file -r org.xfce.Catfish GNOME Utility Filesystem
%fdupes %{buildroot}%{python3_sitelib}
%find_lang %{name}

%if 0%{?suse_version} < 1500
%post
%icon_theme_cache_post

%postun
%icon_theme_cache_postun
%endif

%files
%license COPYING
%doc AUTHORS ChangeLog README
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/org.xfce.Catfish.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.??g
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}_lib
%{python3_sitelib}/%{name}-%{version}-py%{py3_ver}.egg-info
%{_mandir}/man?/%{name}.?%{ext_man}

%files lang -f %{name}.lang

%changelog
* Thu Jan 31 2019 Maurizio Galli <maurizio.galli@gmail.com>
- dropped failing and obsolete --record-rpm build flag (boo#1123781)
* Sun Jan 27 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 1.4.7
  * General:
  - Cleaner, easier to read manpage contents
  - Added information about the --path flag to help and the manpage
  - Updated AppStream requirements to align with the latest spec
  - Replaced project URLs with HTTPS where possible
  * Desktop Integration:
  - The window layout now respects the current desktop (bxo#14486)
  - headerbar layout is used for Budgie, GNOME, and Pantheon
  - All other desktops use the traditional titlebar layout
  - This option can be overridden using the use-headerbar option in the
    Catfish configuration file (~/.config/catfish/catfish.rc)
  - Files can now be dragged into other applications (bxo#14492)
  - For file managers, the files will usually be copied to that
    location
  - For other applications, the files will be opened by the application
  * Performance:
  - Thumbnails will now only be generated when the thumbnail view is
    active (bxo#14689)
  - Added /dev to list of standard excluded directories
  - Files within /dev can still be searched if explicitly selected by
    the user
  * Bug Fixes:
  - Quoted search strings now allow for searching for specific phrases,
    instead of searching for actual quote characters (bxo#14501)
  - The file context menu can now be opened multiple times (bxo#14621)
  - Fix crash as startup with multi-file selection (lp#1753163)
  * Translation Updates
* Sat Jan 19 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 1.4.6
  * Upgraded thumbnailer, based on the FD.o Thumbnail Spec:
  - Improved error handling
  - Proper permissions for thumbnail directories and files
  - Logging of failed thumbnail generation
  - Saving of thumbnail file attributes
  - Support for relative thumbnail directories
  * The minimum GTK+ version has been bumped to 3.16.
  * Added inode/directory mimetype to desktop entry (bxo#14505)
  * Disabled overlay scrollbars to improve interacting with the results
    list (bxo#14487)
  * Enabled launching of executable AppImage files (bxo#14500)
  * Fixed invalid date in appdata (bxo#14502)
  * Replaced stock icons with standard Mime Type icons (bxo#14503)
  * Improved handling of exceptions when parsing settings (bxo#14491)
  * Improved handling of UnicodeDecodeErrors (bxo#14490)
  * Improved handling of PermissionErrors (bxo#14488)
  * Improved support for hidden files (bxo#14497)
  * Remember window size and position between sessions (bxo#14504)
  * Xfce: Open directories with the preferred file manager (bxo#14483)
  * Translation Updates
  - dropped outdated macros
  - added missing dep python3-gobject-Gdk required
* Fri Apr 27 2018 badshah400@gmail.com
- Drop Requires: gnome-icon-theme; all necessary icons are already
  provided by adwaita-icon-theme, a hard requirement for gtk3.
- Only run post(un) scripts on openSUSE < 1500; for later versions
  rpm file triggers take care of updating the icon cache already.
* Sat Apr 14 2018 avvissu@yandex.by
- Update to 1.4.5:
  * Translation Updates:
  - Catalan, Danish, Dutch, Lithuanian, Spanish, Swedish, Turkish
- Spec file cleanup
* Tue Jan 30 2018 avvissu@yandex.by
- Update to 1.4.4:
  * Installer cleanup
  * Updated appdata requirements
  * Add Keywords to desktop file (lintian), extend Categories
    with GTK (desktop-file-validate)
  * Catfish 1.4.3:
  * pycodestyle improvements
  * Improve search speed by discarding .cache and .gvfs when
    possible, add --basename to locate query
  * Stop all search methods when engine is stopped, improve error
    handling with thumbnails
- Update the sourceurl
- Use appdata instead of metainfo
- Fix: non-executable-script
* Tue Jun 13 2017 jengelh@inai.de
- Cure grammar problems in description.
* Sun Apr 10 2016 and.november@opensuse.org
- update to version 1.4.2
* Fri Oct  9 2015 and.november@opensuse.org
- update to version 1.3.3
* Sun Oct  5 2014 and.november@opensuse.org
- update to version 1.2.2
* Mon Mar 10 2014 and.november@opensuse.org
- update to version 1.0.2
* Sun Mar  2 2014 and.november@opensuse.org
- update to version 1.0.1
* Sat Feb  8 2014 and.november@opensuse.org
- update to version 1.0.0
